//(function () {

//  Create your Phaser game and inject it into the gameContainer div.
//  We did it in a window.onload event, but you can do it anywhere (requireJS load, 
//anonymous function, jQuery dom ready, - whatever floats your boat)
var game;

function initPhaser(renderer) {
    document.removeEventListener('mousedown', selectRenderer);
    var click2canvas = document.getElementById('gameContainer');
    click2canvas.parentNode.removeChild(click2canvas);
    
    game = new Phaser.Game(960,540, renderer || Phaser.AUTO, window);


    var createSave = function() {
        var persistent = {
            version: 3, //savegame version
            numdeaths : 0,  //how many times has the character died
            curLvl : 1, //Current Level. Starts with lvl 1
            totalLvls: 15, //Total amount of levels. 
            lvlTime: 0, //Time to finish the level
            perfectTime: null, // Time to beat to get an extra star
            perfectDeaths: null // Max allowed deaths to get an extra star
        };

        persistent.options = {
            soundEnabled : true,
            musicEnabled : true
        };

        persistent.stats = {
           totalDeaths : 0,
            totalTime : 0,
            level : []
        };

        for (var lvl = 1, tLvl = persistent.totalLvls; lvl <= tLvl ; lvl++) {
            persistent.stats.level[lvl] = {
                id: lvl,
                unlocked: false,
                stars: 0,
                numdeaths: null,
                lvlTime: null
            };
        }

        persistent.stats.level[1].unlocked = true;

        return persistent;
    };


    //TODO: Also check saveversion
    var newSave = createSave();

    if (localStorage.getItem('savedData')) {
        console.log('Saved Data found. Checking..');
        var oldData = JSON.parse(localStorage.getItem('savedData'));
        if (oldData.version === newSave.version) {
            console.log('Saved Data valid. Loading..');
            game.persistent = oldData;
        } else {
            console.log('Saved Data invalid. Initializing save..');
            game.persistent = newSave;
            localStorage.setItem('savedData', JSON.stringify(game.persistent));
        }
    } else {
        console.log('Saved Data not found. Initializing save..');
        game.persistent = newSave;
        localStorage.setItem('savedData', JSON.stringify(game.persistent));
    }

    //  You don't have to do this in the html, it could be done in your Boot state too, but for simplicity I'll keep it here.
    game.state.add('Boot', Pichon.Boot);
    game.state.add('Preloader', Pichon.Preloader);
    game.state.add('MainMenu', Pichon.MainMenu);
    game.state.add('LevelSelection', Pichon.LevelSelection);
    game.state.add('Game', Pichon.Game);
    game.state.add('Win', Pichon.Win);
    game.state.add('Credits', Pichon.Credits);
    game.state.add('Buy', Pichon.Buy);

    //  Now start the Boot state.
    game.state.start('Boot');
}

function selectRenderer(e) {
    initPhaser(Phaser.CANVAS);
    clearTimeout(timer);
}

document.addEventListener('mousedown', selectRenderer);
var timer = window.setTimeout(initPhaser, 1500);
//}());
